@@ -18,7 +18,7 @@ OPTIONS = {
     "store_logs" : DEFAULT_STORE,
     "log_in_console" : DEFAULT_LOG_IN_CONSOLE,
     "send_logs" : DEFAULT_SEND,
-    "first_run" : True
+    "first_run" : True,
 }
 
 #Get the thonny workbench object
