@@ -12,6 +12,7 @@ from thonnycontrib.thonny_LoggingPlugin.processing import formatData
 from thonnycontrib.thonny_LoggingPlugin.configuration import configuration
 from thonnycontrib.thonny_LoggingPlugin.configuration.globals import *
 from thonnycontrib.thonny_LoggingPlugin.communication.sendingClient import SendingClient
+from thonnycontrib.thonny_LoggingPlugin.formats.xAPI_creation import convert_to_xAPI
 
 class EventLogger:
     """
@@ -59,7 +60,7 @@ class EventLogger:
             "Open" : {'sequence','editor','text_widget','filename'},
             "SaveAs" : {'sequence','editor','text_widget','filename'},
 
-            "l1Tests" : {'sequence','filename','tested_line','expected_result','obtained_result','exception'}
+            "l1Tests" : {'sequence','filename','tested_line','expected_result','obtained_result','exception','name','lineno','selected'}
         }
 
         for sequence in self._inDict:
@@ -194,22 +195,30 @@ class EventLogger:
         #Ajout contenu éditeur
         if data['sequence'] in {'ShellCommand','Open','Save','SaveAs'} :
             data['editorContent'] = get_workbench().get_editor_notebook().get_current_editor_content()
-        
 
         # Partie traitements
         if data['sequence'] == 'TextInsert' :
             if data["text_widget_class"] == 'ShellText':
+                #Gestion cas de sortie trop lourdes pour l'envoi au serveur
+                if 'text' in data :
+                    if len(data['text']) > 1000 :
+                        data['text'] = "TEXT TOO LONG"
+
                 if not 'value' in data['tags'] and not 'stderr' in data['tags'] and not 'stdout' in data['tags']:
                     if 'prompt' in data['tags']:
                         data = self.send_buffer_error()
                         self._log_event(data,event)
                         self.formatter.end_event()
                         return {}
+                    return {}
                     
                 else :
                     if 'stderr' in data['tags']:
+                        data['text'] = self.cut_filename(data['text'])
                         self._buffer_errors(data)
                         return {}
+            else : 
+                return {}
 
         if data['sequence'] == 'l1Tests':
             if  'exception' in data or 'obtained_result' in data :
@@ -224,7 +233,7 @@ class EventLogger:
                     data['obtained_result'] = data['exception']
 
         if 'filename' in data :
-            data['filename'] = re.search("\/[^\/]*$",data['filename']).group()
+            data['filename'] = self.cut_filename(data['filename'])
             
         return data
 
@@ -252,21 +261,49 @@ class EventLogger:
         self._stderrBuffer = {}
         return data
 
+    def cut_filename(self,s):
+        """
+        Cut the filename to keep only the last part
+
+        Args : 
+            s (str) the filename
+
+        Return :
+            (str) the filename cutted
+        
+        """
+        try :
+            return re.search("\/[^\/]*$",s).group()
+        except Exception as e :
+            return s
+
     def receive_formatted_logs(self,formatted_log):
         """
         Store and send the formatted logs in parameter to a Server if the user didn't desactivate it
         Args :
             formatted_log (object:'dict') the logs in a basic exportation format
         """
-        #Pour l'instant, on stocke aussi une trace localement:
         if formatted_log != {}:
             self.formatted_logs.append(formatted_log)
             if self.log_in_console :
                 print(formatted_log)
-            try :
-                if self.sending_logs :
-                    self.sending_client.send_xapi_statement(formatted_log)
+            if self.sending_logs :
+                try :
+                        self.send_xAPI_statement(formatted_log)
+                except KeyError as e :
+                    logging.info(formatted_log,e)
+                    return 
 
-            except KeyError as e :
-                logging.info(formatted_log,e)
-                return 
\ No newline at end of file
+    def send_xAPI_statement(self,formatted_log):
+        """
+        Convert data to the xAPI format, and send it to the LRS
+
+        Args :
+            data (object: dict()): dict of the data in a basic format
+        """
+        xAPI_statement = convert_to_xAPI(formatted_log)
+        try :
+            self.sending_client.send(xAPI_statement,"/statements/")
+        except Exception as e:
+            self.sending_logs = False
+            logging.warning(" Server can't be reach, restart Thonny to retry\n"+str(e))
\ No newline at end of file
