@@ -137,6 +137,7 @@ class FormatData:
             'userID': self.userID,
             'sessionID':  self.sessionID
         }
+        self.current['L1Test'] = self.checks_if_plugin_installed('thonnycontrib.l1test')
         self.end_event()
 
     def end_session(self, id):
@@ -155,4 +156,8 @@ class FormatData:
         self.end_event()
 
     def isOnProgress(self):
-        return self.on_progress
\ No newline at end of file
+        return self.on_progress
+
+    def checks_if_plugin_installed(self,name):
+        import sys
+        return name in sys.modules
\ No newline at end of file
